#!/usr/bin/env python3
from pathlib import Path
import re
import pandas


# converts a cnrs geslab type t001 report to a single table
def sifact002_to_sheet(sifact002_dir: Path, out_tsv_file_path: Path):

    dept_names = [
        'DIRECTION',
        'MAT.NANO.SCIENCES',
        'MATERIAUX ET LUMIERE',
        'MATIERE MOLLE',
        'MECA VERRES',
        'MILIEU DIVISE',
        'PHYSIQUE MOLECULAIRE'
    ]

    with open(out_tsv_file_path, 'wt') as outf:
        out_header_has_been_written = False
        for dept_name in dept_names:
            src_file_path = sifact002_dir / ('2019.' + dept_name + '.xls')
            tmp_file_path = Path('./tmp') / ('2019.' + dept_name + '.tsv')
            df = pandas.read_excel(src_file_path)
            df.to_csv(tmp_file_path, sep='\t')

            with open(tmp_file_path) as inf:
                in_header_has_been_read = False
                for line in inf.readlines():
                    if in_header_has_been_read:
                        outf.write(line)
                    else:
                        # this line is the header only output it if it's the 1st header
                        in_header_has_been_read = True
                        if not out_header_has_been_written:
                            outf.write(line)
                            out_header_has_been_written = True

    # add an index
    df = pandas.read_csv(out_tsv_file_path, sep='\t')
    # df.rename(columns={0: 'uid'})
    # df['id'] = range(1, len(df) + 1)
    # df.insert(0, 'id', df.pop('id'))
    # df = df[-1:] + df[:-1]  # put the id column in the first column
    df.to_csv(out_tsv_file_path, sep='\t')

    # with open(in_tsv_file_path) as inf, open(out_tsv_file_path, 'wt') as outf:
    #     table_header_has_been_written = False
    #     for line in inf.readlines():
    #         ignore_line = False
    #         # Entité dépensière : 				AESJULLIEN		AES RENNES METROPOLE MC JULLIEN									Crédits reçus : 								40,000.00
    #         # 															Disponible : 								24,743.14
    #         #
    #         #
    #         # N° commande	Souche		Libellé commande				Date commande	Raison sociale fournisseur	Montant consommé sur exercice antérieur	Montant consommé sur l'exercice			Montant réservé					Montant facturé		Code origine	Nature dépense	Statut		Cde groupée
    #         if re.match(r'^Entité dépensière', line):
    #             ignore_line = True  # noqa
    #         is_table_header = re.match(r'^N° commande', line) is not None
    #         # 19,572.00	19AESMCJ		CAMERA ZYLA 5.5 sCMOS				04/11/19	ANDOR TECHNOLOGY LIMITED	0.00	13,681.56			0.00					0.00		635991	IM
    #         if is_table_header and not table_header_has_been_written:
    #             outf.write('# %s' % line)
    #             table_header_has_been_written = True
    #         if re.match(r'^[0-9,./]+\t', line):
    #             outf.write(line)


def sifact002_to_itorders(sifact002_dir: Path, itorders_file_path: Path):
    sheet_file_path = Path('./tmp/commandes-2019-ur1.tsv')
    sifact002_to_sheet(sifact002_dir, sheet_file_path)

    df = pandas.read_csv(sheet_file_path, sep='\t')

    # delete the colums for which the label is of the form 'Unnamed: <n>'. They come from the csv export of libre office
    unnamed_columns = [column_label for column_label in df.keys() if re.match(r'^Unnamed', column_label) is not None]
    print(unnamed_columns)
    df = df.drop(columns=unnamed_columns)

    print(df.columns)
    print(df.keys())
    print(df)
    it_df = df[(df['Fournisseur/Division fourn.'] == '7976       DELL') | 
               (df['Fournisseur/Division fourn.'] == '16783      ECONOCOM') | 
               (df['Fournisseur/Division fourn.'] == '4945       MISCO INMAC WSTORE')
               ]

    # 'AMAZON EU SARL SUCCURSALE FRANCAISE'
    # 'INMAC'
    # 'RETIS'
    # 'APIXIT'
    print(it_df)

    # print(it_df[['Montant facturé', 'Raison sociale fournisseur', 'Libellé commande']])
    it_df.to_csv(itorders_file_path, sep='\t')


def main():
    sifact002_to_itorders(Path('./achats-ipr/2019/ur1/from_ddemorel'), Path('./tmp/commandes-it-2019-ur1-002.tsv'))


main()
